@@ -67,4 +67,4 @@ class AlgorithmDaemon:
         self.__worker_stub.ReportStatus(ReportStatusRequest(
             clientAddress=WorkerIdentity,
             status=ReportStatusRequest.Faulted,
-            message=str(exception), timeout=3))
+            message=str(exception)), timeout=3)
